----------------------------------------------------------------------------------
-- Project Name: Gage Hash Function, C: 224 and r: 8
-- 
-- Copyright 2019:
--     Mohamed El-Hadedy <mealy@cpp.edu>
--     Danilo Gligoroski <danilog@ntnu.no>
-- 
-- This program is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License as
-- published by the Free Software Foundation; either version 2 of the
-- License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful, but
-- WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-- General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-- 02110-1301, USA.
-- 
----------------------------------------------------------------------------------
----------------------------------------------------------------------------------
-- Company: California State Polytechnic University, Pomona, Norwegian University of Science and Technology (NTNU)
-- Engineer-1: Assistant Professor at ECE-department, College of Engineering 
-- Engineer-2: Professor at Department of Information Security and Communication Technology
-- 
-- Create Date: 06/22/2019 02:06:31 PM
-- Design Name-1: Mohamed El-Hadedy, also Airforce Research Lab(AFRL) fellow, US-AFA
-- Design Name-2: Danilo Gligoroski, also Visiting professor: Department of Mathematics and Statistics, University of South Florida, USA

-- Module Name: Leader ROM - Behavioral
-- Project Name: Gage Hash Function , C: 224 and r: 8
-- Target Devices: xc7a35tcpg236-1 
-- Tool Versions: Vivado 2019.1
-- Description: Hash function Engine (FIFO for storing the message coming from the main testbench (can be coming from any serial communication protocol as PCI-E or UART, USB, SPI, I2C or more)
-- 
-- Dependencies: 
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx leaf cells in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Leader is
    Port ( LDR_INP : in STD_LOGIC_VECTOR (4 downto 0);
           LDR_OP : out STD_LOGIC_VECTOR (1 downto 0));
end Leader;

architecture Behavioral of Leader is

begin
LDR: process(LDR_INP)
begin 
COMP_CASE: case (LDR_INP) IS 
                    when "00000" => LDR_OP <= "00";
                    when "00001" => LDR_OP <= "11";
                    when "00010" => LDR_OP <= "00";
                    when "00011" => LDR_OP <= "11";
                    when "00100" => LDR_OP <= "00";
                    when "00101" => LDR_OP <= "01";
                    when "00110" => LDR_OP <= "10";
                    when "00111" => LDR_OP <= "11";
                    when "01000" => LDR_OP <= "10";
                    when "01001" => LDR_OP <= "01";
                    when "01010" => LDR_OP <= "10";
                    when "01011" => LDR_OP <= "11";
                    when "01100" => LDR_OP <= "10";
                    when "01101" => LDR_OP <= "01";
                    when "01110" => LDR_OP <= "10";
                    when "01111" => LDR_OP <= "11";
                    when "10000" => LDR_OP <= "00";
                    when "10001" => LDR_OP <= "01";
                    when "10010" => LDR_OP <= "10";
                    when "10011" => LDR_OP <= "11";
                    when "10100" => LDR_OP <= "10";
                    when "10101" => LDR_OP <= "11";
                    when "10110" => LDR_OP <= "00";
                    when "10111" => LDR_OP <= "11";
                    when "11000" => LDR_OP <= "10";
                    when "11001" => LDR_OP <= "11";
                    when "11010" => LDR_OP <= "10";
                    when "11011" => LDR_OP <= "11";
                    when "11100" => LDR_OP <= "10";
                    when "11101" => LDR_OP <= "01";
                    when "11110" => LDR_OP <= "10";
                    when "11111" => LDR_OP <= "01";
                    when others => LDR_OP <= (others =>'Z');
               end case; 

end process; 

end Behavioral;
